@@ -862,11 +862,11 @@ go back to ((<Index>))
 --- NArrayMiss#mask(mask)
      return (({NArrayMiss#get_mask!&((|mask|))})).
 --- NArrayMiss#all?
-     return true if all the valid elements are not 0 else, false.
+     return true if all the valid elements are not 0, else false.
 --- NArrayMiss#any?
-     return true if any valid element is not 0 else, false.
+     return true if any valid element is not 0, else false.
 --- NArrayMiss#none?
-     return true if none of the valid elements is not 0 else, false.
+     return true if none of the valid elements is not 0, else false.
 --- NArrayMiss#where
      return (({NArray})) of indices where valid elements are not 0.
 --- NArrayMiss#where2
@@ -1006,6 +1006,14 @@ go back to ((<Index>))
      return (({NArray})) as data.
 --- NArrayMiss#valid?
      return (({Array})) whose elements are true or false corresponding to valid or invalid of elements, respectively.
+--- NArrayMiss#all_valid?
+     return true if all elements are valid, else false.
+--- NArrayMiss#none_valid?
+     return true if all elements are invalid, else false.
+--- NArrayMiss#all_invalid?
+     alias to none_valid?
+--- NArrayMiss#any_valid?
+     return true if any elements are valid, else false.
      
 --- NArrayMiss#count_valid
      return the number of valid elements.
@@ -1085,6 +1093,16 @@ go back to ((<Index>))
     end
     tf
   end
+  def all_valid?
+    @mask.all?
+  end
+  def none_valid?
+    @mask.none?
+  end
+  alias :all_invalid? :none_valid?
+  def any_valid?
+    @mask.any?
+  end
 
   def count_valid(*arg)
     if arg.length==0 then
